gnome-core-1.4.1 stable port information

Package: gnome-core
Version: 1.4.1
Revision: 19
Source: mirror:gnome:sources/%n/1.4/%n-%v.tar.bz2
Source-MD5: fea00c24018057a6f04315bea8e4bdab
Depends: <<
%N-shlibs (= %v-%r),
control-center-shlibs (>= 1.4.0.5-16),
gnome-print-shlibs (>= 0.36-11),
rarian-compat
<<
Conflicts: <<
gnome-session (>= 2.16.0-1),
gnome-terminal (>= 2.16.0-1),
gnome-panel (>= 2.16.0-1),
gnome-desktop
<<
Replaces: <<
gnome-session (>= 2.16.0-1),
gnome-terminal (>= 2.16.0-1),
gnome-panel (>= 2.16.0-1),
gnome-desktop
<<
BuildDepends: <<
audiofile,
bzip2-dev,
control-center-dev (>= 1.4.0.5-16),
esound (>= 0.2.38-1),
fink (>= 0.24.12-1),
gdk-pixbuf (>= 0.18.0-12),
gettext-bin,
gettext-dev,
gettext-tools,
glib,
gnome-libs-dev (>= 1.4.2-19),
gnome-print-dev (>= 0.36-11),
gtk+ (>= 1.2.10-20),
gtk-doc (>= 1.8-1),
gtkhtml-dev,
imlib (>= 1.9.14-14),
libglade (>= 0.17-13),
libjpeg,
libpng3,
libxml,
orbit-dev (>= 0.5.17-15)
<<
PatchFile: %n-%v.patch
PatchFile-MD5: c60e28cf0e27cbbc60f201e580d48b43

# Fix __PRETTY_FUNCTION__ becoming a variable
PatchScript: <<
%{default_script}
find . -name '*.c' | xargs perl -0777 -i -pe 's/(G_GNUC_PRETTY_FUNCTION)\s*"(.*?)"\s*([,)])/"%%s$2",$1$3/smg'
<<

NoSetLDFLAGS: true
SetLIBS: -L%p/lib
SetCFLAGS: -O2
ConfigureParams: --mandir=%p/share/man
InstallScript: <<
make install DESTDIR=%d

mv %i/bin/gnome-session %i/bin/gnome-session-real
echo '#!/bin/sh' >%i/bin/gnome-session
echo 'exec gnome-session-real --no-xshm "$@"' >>%i/bin/gnome-session
chmod 755 %i/bin/gnome-session

mv %i/bin/panel %i/bin/panel-real
echo '#!/bin/sh' >%i/bin/panel
echo 'exec panel-real --no-xshm "$@"' >>%i/bin/panel
chmod 755 %i/bin/panel
<<
SplitOff: <<
Package: %N-shlibs
Depends: gdk-pixbuf-shlibs (>= 0.18.0-12), gnome-libs-shlibs (>= 1.4.2-19)
Replaces: %N (<= 1.4.0.6-2)
Files: lib/libpanel_applet.*.dylib lib/libpanel_status.*.dylib
Shlibs: <<
%p/lib/libpanel_applet.0.dylib 1.0.0 %n (>= 1.4.1-1)
%p/lib/libpanel_status.0.dylib 1.0.0 %n (>= 1.4.1-1)
<<
DocFiles: AUTHORS COPYING* ChangeLog NEWS README
<<
SplitOff2: <<
Package: %N-dev
BuildDependsOnly: True
Depends: %N-shlibs (= %v-%r)
Replaces: %N (<< 1.4.0.8-3)
Files: include lib/*.dylib lib/*.a lib/*.la lib/*.sh
DocFiles: AUTHORS COPYING* ChangeLog NEWS README
<<
DocFiles: AUTHORS COPYING* ChangeLog NEWS README
PostInstScript: <<
if [ configure = "$1" ]; then
scrollkeeper-update -q
fi
<<
PostRmScript: <<
if [ remove = "$1" ]; then
scrollkeeper-update -q
fi
<<
Description: Common files for Gnome core apps
DescPort: <<
It is important to compile the gtk+ package under OS X 10.1.1 to avoid
crashes in some applets.
<<
License: GPL/GFDL
Maintainer: None
DescPackaging: <<
Originally packaged by Masanori Sekino.
<<
Homepage: http://www.gnome.org/

gnome-core-1.4.1 stable port .patch

diff -Naur gnome-core-1.4.1-0001/applets/fish/Makefile.in gnome-core-1.4.1-0002/applets/fish/Makefile.in
--- gnome-core-1.4.1-0001/applets/fish/Makefile.in 2002-06-07 19:11:15.000000000 -0400
+++ gnome-core-1.4.1-0002/applets/fish/Makefile.in 2006-03-19 21:49:40.000000000 -0500
@@ -236,7 +236,7 @@

DEFS = @DEFS@ -I. -I$(srcdir) -I../..
LIBS = @LIBS@
-libfish_applet_la_LDFLAGS =
+libfish_applet_la_LDFLAGS = -module
libfish_applet_la_LIBADD =
libfish_applet_la_OBJECTS = fish.lo
COMPILE = $(CC) $(DEFS) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS)
diff -Naur gnome-core-1.4.1-0001/applets/gen_util/Makefile.in gnome-core-1.4.1-0002/applets/gen_util/Makefile.in
--- gnome-core-1.4.1-0001/applets/gen_util/Makefile.in 2002-06-07 19:11:21.000000000 -0400
+++ gnome-core-1.4.1-0002/applets/gen_util/Makefile.in 2006-03-19 21:49:40.000000000 -0500
@@ -246,7 +246,7 @@

DEFS = @DEFS@ -I. -I$(srcdir) -I../..
LIBS = @LIBS@
-libgen_util_applet_la_LDFLAGS =
+libgen_util_applet_la_LDFLAGS = -module
libgen_util_applet_la_LIBADD =
libgen_util_applet_la_OBJECTS = main.lo mailcheck.lo popcheck.lo \
printer.lo clock.lo remote-helper.lo
diff -Naur gnome-core-1.4.1-0001/applets/tasklist/Makefile.in gnome-core-1.4.1-0002/applets/tasklist/Makefile.in
--- gnome-core-1.4.1-0001/applets/tasklist/Makefile.in 2002-06-07 19:11:39.000000000 -0400
+++ gnome-core-1.4.1-0002/applets/tasklist/Makefile.in 2006-03-19 21:49:40.000000000 -0500
@@ -259,7 +259,7 @@
tasklist_menu.$(OBJEXT) tasklist_properties.$(OBJEXT) gstc.$(OBJEXT) \
gwmh.$(OBJEXT)
tasklist_applet_DEPENDENCIES = ../../panel/libpanel_applet.la
-tasklist_applet_LDFLAGS =
+tasklist_applet_LDFLAGS = -module
COMPILE = $(CC) $(DEFS) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS)
LTCOMPILE = $(LIBTOOL) --mode=compile $(CC) $(DEFS) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS)
CCLD = $(CC)
diff -Naur gnome-core-1.4.1-0001/configure gnome-core-1.4.1-0002/configure
--- gnome-core-1.4.1-0001/configure 2002-06-07 17:22:54.000000000 -0400
+++ gnome-core-1.4.1-0002/configure 2006-03-19 21:49:40.000000000 -0500
@@ -3962,11 +3962,11 @@
;;

darwin* | rhapsody*)
- allow_undefined_flag='-undefined suppress'
+ allow_undefined_flag='-undefined suppress -flat_namespace'
# FIXME: Relying on posixy $() will cause problems for
# cross-compilation, but unfortunately the echo tests do not
# yet detect zsh echo's removal of \ escapes.
- archive_cmds='$CC $(test .$module = .yes && echo -bundle || echo -dynamiclib) $allow_undefined_flag -o $lib $libobjs $deplibs$linkopts -install_name $rpath/$soname $(test -n "$verstring" -a x$verstring != x0.0 && echo $verstring)'
+ archive_cmds='$CC $(test .$module = .yes && echo -bundle || echo -dynamiclib) $allow_undefined_flag -o $lib $libobjs $deplibs$linkopts $(test .$module != .yes && echo -install_name $rpath/$soname $tmp_verstring)'
# We need to add '_' to the symbols in $export_symbols first
#archive_expsym_cmds="$archive_cmds"' && strip -s $export_symbols'
hardcode_direct=yes
diff -Naur gnome-core-1.4.1-0001/help-browser/gnome-help-browser.c gnome-core-1.4.1-0002/help-browser/gnome-help-browser.c
--- gnome-core-1.4.1-0001/help-browser/gnome-help-browser.c 2001-10-26 05:13:26.000000000 -0400
+++ gnome-core-1.4.1-0002/help-browser/gnome-help-browser.c 2006-03-19 21:49:40.000000000 -0500
@@ -81,8 +81,8 @@
void destroy_server(HelpWindow win);

/* MANPATH should probably come from somewhere */
-#define DEFAULT_MANPATH GNOME_PREFIX "/man:/usr/man:/usr/share/man:/usr/local/man:/usr/X11R6/man"
-#define DEFAULT_INFOPATH GNOME_PREFIX "/info:/usr/info:/usr/share/info:/usr/local/info"
+#define DEFAULT_MANPATH GNOME_PREFIX "/share/man:/usr/share/man:/usr/local/share/man:/usr/X11R6/man"
+#define DEFAULT_INFOPATH GNOME_PREFIX "/share/info:/usr/share/info:/usr/local/share/info"
/* GHELPPATH probably needs some automatic additions inside toc */
#define DEFAULT_GHELPPATH GNOME_PREFIX "/share/gnome/help:" \
"/opt/gnome/share/gnome/help:" \
diff -Naur gnome-core-1.4.1-0001/ltmain.sh gnome-core-1.4.1-0002/ltmain.sh
--- gnome-core-1.4.1-0001/ltmain.sh 2002-06-07 17:22:40.000000000 -0400
+++ gnome-core-1.4.1-0002/ltmain.sh 2006-03-19 21:49:41.000000000 -0500
@@ -2862,6 +2862,11 @@
if test -n "$export_symbols" && test -n "$archive_expsym_cmds"; then
eval cmds=\"$archive_expsym_cmds\"
else
+ if test "x$verstring" = "x0.0"; then
+ tmp_verstring=
+ else
+ tmp_verstring="$verstring"
+ fi
eval cmds=\"$archive_cmds\"
fi
IFS="${IFS= }"; save_ifs="$IFS"; IFS='~'
diff -Naur gnome-core-1.4.1-0001/omf-install/Makefile.in gnome-core-1.4.1-0002/omf-install/Makefile.in
--- gnome-core-1.4.1-0001/omf-install/Makefile.in 2002-06-07 19:11:43.000000000 -0400
+++ gnome-core-1.4.1-0002/omf-install/Makefile.in 2006-03-19 21:49:41.000000000 -0500
@@ -300,7 +300,6 @@
-for file in $(srcdir)/*.omf; do \
$(INSTALL_DATA) $(srcdir)/$$file $(DESTDIR)$(omf_dest_dir); \
done
- -scrollkeeper-update -p $(scrollkeeper_localstate_dir)

uninstall-local:
-for file in $(srcdir)/*.omf; do \
diff -Naur gnome-core-1.4.1-0001/po/Makefile.in.in gnome-core-1.4.1-0002/po/Makefile.in.in
--- gnome-core-1.4.1-0001/po/Makefile.in.in 2002-06-07 17:22:39.000000000 -0400
+++ gnome-core-1.4.1-0002/po/Makefile.in.in 2006-03-19 21:49:41.000000000 -0500
@@ -106,7 +106,10 @@
@catalogs='$(CATALOGS)'; \
for cat in $$catalogs; do \
cat=`basename $$cat`; \
- lang=`echo $$cat | sed 's/\.gmo$$//'`; \
+ case "$$cat" in \
+ *.gmo) lang=`echo $$cat | sed 's/\.gmo$$//'` ;; \
+ *.mo) lang=`echo $$cat | sed 's/\.mo$$//'` ;; \
+ esac; \
dir=$(localedir)/$$lang/LC_MESSAGES; \
$(mkinstalldirs) $(DESTDIR)$$dir; \
if test -r $$cat; then \

gnome-core-1.4.1 _unstable_ port information

Package: gnome-core
Version: 1.4.1
Revision: 19
Source: mirror:gnome:sources/%n/1.4/%n-%v.tar.bz2
Source-MD5: fea00c24018057a6f04315bea8e4bdab
Depends: <<
%N-shlibs (= %v-%r),
control-center-shlibs (>= 1.4.0.5-16),
gnome-print-shlibs (>= 0.36-11),
rarian-compat
<<
Conflicts: <<
gnome-session (>= 2.16.0-1),
gnome-terminal (>= 2.16.0-1),
gnome-panel (>= 2.16.0-1),
gnome-desktop
<<
Replaces: <<
gnome-session (>= 2.16.0-1),
gnome-terminal (>= 2.16.0-1),
gnome-panel (>= 2.16.0-1),
gnome-desktop
<<
BuildDepends: <<
audiofile,
bzip2-dev,
control-center-dev (>= 1.4.0.5-16),
esound (>= 0.2.38-1),
fink (>= 0.24.12-1),
gdk-pixbuf (>= 0.18.0-12),
gettext-bin,
gettext-dev,
gettext-tools,
glib,
gnome-libs-dev (>= 1.4.2-19),
gnome-print-dev (>= 0.36-11),
gtk+ (>= 1.2.10-20),
gtk-doc (>= 1.8-1),
gtkhtml-dev,
imlib (>= 1.9.14-14),
libglade (>= 0.17-13),
libjpeg,
libpng3,
libxml,
orbit-dev (>= 0.5.17-15)
<<
PatchFile: %n-%v.patch
PatchFile-MD5: c60e28cf0e27cbbc60f201e580d48b43

# Fix __PRETTY_FUNCTION__ becoming a variable
PatchScript: <<
%{default_script}
find . -name '*.c' | xargs perl -0777 -i -pe 's/(G_GNUC_PRETTY_FUNCTION)\s*"(.*?)"\s*([,)])/"%%s$2",$1$3/smg'
<<

NoSetLDFLAGS: true
SetLIBS: -L%p/lib
SetCFLAGS: -O2
ConfigureParams: --mandir=%p/share/man
InstallScript: <<
make install DESTDIR=%d

mv %i/bin/gnome-session %i/bin/gnome-session-real
echo '#!/bin/sh' >%i/bin/gnome-session
echo 'exec gnome-session-real --no-xshm "$@"' >>%i/bin/gnome-session
chmod 755 %i/bin/gnome-session

mv %i/bin/panel %i/bin/panel-real
echo '#!/bin/sh' >%i/bin/panel
echo 'exec panel-real --no-xshm "$@"' >>%i/bin/panel
chmod 755 %i/bin/panel
<<
SplitOff: <<
Package: %N-shlibs
Depends: gdk-pixbuf-shlibs (>= 0.18.0-12), gnome-libs-shlibs (>= 1.4.2-19)
Replaces: %N (<= 1.4.0.6-2)
Files: lib/libpanel_applet.*.dylib lib/libpanel_status.*.dylib
Shlibs: <<
%p/lib/libpanel_applet.0.dylib 1.0.0 %n (>= 1.4.1-1)
%p/lib/libpanel_status.0.dylib 1.0.0 %n (>= 1.4.1-1)
<<
DocFiles: AUTHORS COPYING* ChangeLog NEWS README
<<
SplitOff2: <<
Package: %N-dev
BuildDependsOnly: True
Depends: %N-shlibs (= %v-%r)
Replaces: %N (<< 1.4.0.8-3)
Files: include lib/*.dylib lib/*.a lib/*.la lib/*.sh
DocFiles: AUTHORS COPYING* ChangeLog NEWS README
<<
DocFiles: AUTHORS COPYING* ChangeLog NEWS README
PostInstScript: <<
if [ configure = "$1" ]; then
scrollkeeper-update -q
fi
<<
PostRmScript: <<
if [ remove = "$1" ]; then
scrollkeeper-update -q
fi
<<
Description: Common files for Gnome core apps
DescPort: <<
It is important to compile the gtk+ package under OS X 10.1.1 to avoid
crashes in some applets.
<<
License: GPL/GFDL
Maintainer: None
DescPackaging: <<
Originally packaged by Masanori Sekino.
<<
Homepage: http://www.gnome.org/

gnome-core-1.4.1 _unstable_ port .patch

diff -Naur gnome-core-1.4.1-0001/applets/fish/Makefile.in gnome-core-1.4.1-0002/applets/fish/Makefile.in
--- gnome-core-1.4.1-0001/applets/fish/Makefile.in 2002-06-07 19:11:15.000000000 -0400
+++ gnome-core-1.4.1-0002/applets/fish/Makefile.in 2006-03-19 21:49:40.000000000 -0500
@@ -236,7 +236,7 @@

DEFS = @DEFS@ -I. -I$(srcdir) -I../..
LIBS = @LIBS@
-libfish_applet_la_LDFLAGS =
+libfish_applet_la_LDFLAGS = -module
libfish_applet_la_LIBADD =
libfish_applet_la_OBJECTS = fish.lo
COMPILE = $(CC) $(DEFS) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS)
diff -Naur gnome-core-1.4.1-0001/applets/gen_util/Makefile.in gnome-core-1.4.1-0002/applets/gen_util/Makefile.in
--- gnome-core-1.4.1-0001/applets/gen_util/Makefile.in 2002-06-07 19:11:21.000000000 -0400
+++ gnome-core-1.4.1-0002/applets/gen_util/Makefile.in 2006-03-19 21:49:40.000000000 -0500
@@ -246,7 +246,7 @@

DEFS = @DEFS@ -I. -I$(srcdir) -I../..
LIBS = @LIBS@
-libgen_util_applet_la_LDFLAGS =
+libgen_util_applet_la_LDFLAGS = -module
libgen_util_applet_la_LIBADD =
libgen_util_applet_la_OBJECTS = main.lo mailcheck.lo popcheck.lo \
printer.lo clock.lo remote-helper.lo
diff -Naur gnome-core-1.4.1-0001/applets/tasklist/Makefile.in gnome-core-1.4.1-0002/applets/tasklist/Makefile.in
--- gnome-core-1.4.1-0001/applets/tasklist/Makefile.in 2002-06-07 19:11:39.000000000 -0400
+++ gnome-core-1.4.1-0002/applets/tasklist/Makefile.in 2006-03-19 21:49:40.000000000 -0500
@@ -259,7 +259,7 @@
tasklist_menu.$(OBJEXT) tasklist_properties.$(OBJEXT) gstc.$(OBJEXT) \
gwmh.$(OBJEXT)
tasklist_applet_DEPENDENCIES = ../../panel/libpanel_applet.la
-tasklist_applet_LDFLAGS =
+tasklist_applet_LDFLAGS = -module
COMPILE = $(CC) $(DEFS) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS)
LTCOMPILE = $(LIBTOOL) --mode=compile $(CC) $(DEFS) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS)
CCLD = $(CC)
diff -Naur gnome-core-1.4.1-0001/configure gnome-core-1.4.1-0002/configure
--- gnome-core-1.4.1-0001/configure 2002-06-07 17:22:54.000000000 -0400
+++ gnome-core-1.4.1-0002/configure 2006-03-19 21:49:40.000000000 -0500
@@ -3962,11 +3962,11 @@
;;

darwin* | rhapsody*)
- allow_undefined_flag='-undefined suppress'
+ allow_undefined_flag='-undefined suppress -flat_namespace'
# FIXME: Relying on posixy $() will cause problems for
# cross-compilation, but unfortunately the echo tests do not
# yet detect zsh echo's removal of \ escapes.
- archive_cmds='$CC $(test .$module = .yes && echo -bundle || echo -dynamiclib) $allow_undefined_flag -o $lib $libobjs $deplibs$linkopts -install_name $rpath/$soname $(test -n "$verstring" -a x$verstring != x0.0 && echo $verstring)'
+ archive_cmds='$CC $(test .$module = .yes && echo -bundle || echo -dynamiclib) $allow_undefined_flag -o $lib $libobjs $deplibs$linkopts $(test .$module != .yes && echo -install_name $rpath/$soname $tmp_verstring)'
# We need to add '_' to the symbols in $export_symbols first
#archive_expsym_cmds="$archive_cmds"' && strip -s $export_symbols'
hardcode_direct=yes
diff -Naur gnome-core-1.4.1-0001/help-browser/gnome-help-browser.c gnome-core-1.4.1-0002/help-browser/gnome-help-browser.c
--- gnome-core-1.4.1-0001/help-browser/gnome-help-browser.c 2001-10-26 05:13:26.000000000 -0400
+++ gnome-core-1.4.1-0002/help-browser/gnome-help-browser.c 2006-03-19 21:49:40.000000000 -0500
@@ -81,8 +81,8 @@
void destroy_server(HelpWindow win);

/* MANPATH should probably come from somewhere */
-#define DEFAULT_MANPATH GNOME_PREFIX "/man:/usr/man:/usr/share/man:/usr/local/man:/usr/X11R6/man"
-#define DEFAULT_INFOPATH GNOME_PREFIX "/info:/usr/info:/usr/share/info:/usr/local/info"
+#define DEFAULT_MANPATH GNOME_PREFIX "/share/man:/usr/share/man:/usr/local/share/man:/usr/X11R6/man"
+#define DEFAULT_INFOPATH GNOME_PREFIX "/share/info:/usr/share/info:/usr/local/share/info"
/* GHELPPATH probably needs some automatic additions inside toc */
#define DEFAULT_GHELPPATH GNOME_PREFIX "/share/gnome/help:" \
"/opt/gnome/share/gnome/help:" \
diff -Naur gnome-core-1.4.1-0001/ltmain.sh gnome-core-1.4.1-0002/ltmain.sh
--- gnome-core-1.4.1-0001/ltmain.sh 2002-06-07 17:22:40.000000000 -0400
+++ gnome-core-1.4.1-0002/ltmain.sh 2006-03-19 21:49:41.000000000 -0500
@@ -2862,6 +2862,11 @@
if test -n "$export_symbols" && test -n "$archive_expsym_cmds"; then
eval cmds=\"$archive_expsym_cmds\"
else
+ if test "x$verstring" = "x0.0"; then
+ tmp_verstring=
+ else
+ tmp_verstring="$verstring"
+ fi
eval cmds=\"$archive_cmds\"
fi
IFS="${IFS= }"; save_ifs="$IFS"; IFS='~'
diff -Naur gnome-core-1.4.1-0001/omf-install/Makefile.in gnome-core-1.4.1-0002/omf-install/Makefile.in
--- gnome-core-1.4.1-0001/omf-install/Makefile.in 2002-06-07 19:11:43.000000000 -0400
+++ gnome-core-1.4.1-0002/omf-install/Makefile.in 2006-03-19 21:49:41.000000000 -0500
@@ -300,7 +300,6 @@
-for file in $(srcdir)/*.omf; do \
$(INSTALL_DATA) $(srcdir)/$$file $(DESTDIR)$(omf_dest_dir); \
done
- -scrollkeeper-update -p $(scrollkeeper_localstate_dir)

uninstall-local:
-for file in $(srcdir)/*.omf; do \
diff -Naur gnome-core-1.4.1-0001/po/Makefile.in.in gnome-core-1.4.1-0002/po/Makefile.in.in
--- gnome-core-1.4.1-0001/po/Makefile.in.in 2002-06-07 17:22:39.000000000 -0400
+++ gnome-core-1.4.1-0002/po/Makefile.in.in 2006-03-19 21:49:41.000000000 -0500
@@ -106,7 +106,10 @@
@catalogs='$(CATALOGS)'; \
for cat in $$catalogs; do \
cat=`basename $$cat`; \
- lang=`echo $$cat | sed 's/\.gmo$$//'`; \
+ case "$$cat" in \
+ *.gmo) lang=`echo $$cat | sed 's/\.gmo$$//'` ;; \
+ *.mo) lang=`echo $$cat | sed 's/\.mo$$//'` ;; \
+ esac; \
dir=$(localedir)/$$lang/LC_MESSAGES; \
$(mkinstalldirs) $(DESTDIR)$$dir; \
if test -r $$cat; then \
diff -Naur gnome-core-1.4.1-0001/applets/desk-guide/gwmthumbnail.c gnome-core-1.4.1-0002/applets/desk-guide/gwmthumbnail.c
--- gnome-core-1.4.1-0001/applets/desk-guide/gwmthumbnail.c 2001-10-26 05:12:47.000000000 -0400
+++ gnome-core-1.4.1-0002/applets/desk-guide/gwmthumbnail.c 2006-03-19 21:50:02.000000000 -0500
@@ -18,35 +18,38 @@
*/
#include "gwmthumbnail.h"

-
#define USE_SHM // FIXME

#define EPSILON (1.0/65536.0) /* 16bit EPSILON should be good enough */

-
/* --- defines --- */
#define SHM_IMAGE_HEIGHT (32)

-
/* --- Gdk & GdkPixbuf compat prototypes --- */
-GdkImage* gdk_image_get (GdkWindow *window,
+static
+GdkImage* s_gdk_image_get (GdkWindow *window,
gint x,
gint y,
gint width,
gint height);
-GdkColormap* gdk_window_get_colormap (GdkWindow *window);
-GdkVisual* gdk_window_get_visual (GdkWindow *window);
-GdkImage* gdk_image_new_shared_with_pixmap (GdkWindow *window,
+static
+GdkColormap* s_gdk_window_get_colormap (GdkWindow *window);
+static
+GdkVisual* s_gdk_window_get_visual (GdkWindow *window);
+static
+GdkImage* s_gdk_image_new_shared_with_pixmap (GdkWindow *window,
gint width,
gint height,
GdkPixmap **pixmap_p);
-GdkPixbuf* gdk_pixbuf_from_image (GdkImage *image,
+static
+GdkPixbuf* s_gdk_pixbuf_from_image (GdkImage *image,
guint x,
guint y,
guint width,
guint height,
GdkColormap *cmap);
-void gdk_pixbuf_copy_from_image (GdkPixbuf *pixbuf,
+static
+void s_gdk_pixbuf_copy_from_image (GdkPixbuf *pixbuf,
guint dest_x,
guint dest_y,
GdkImage *image,
@@ -56,7 +59,6 @@
guint height,
GdkColormap *cmap);

-
/* --- structures --- */
typedef struct _ThumbSize ThumbSize;
struct _ThumbSize
@@ -67,12 +69,10 @@
guint height;
};

-
/* --- variables --- */
static gboolean gwm_thumb_nails_enabled = FALSE;
static GSList *gwm_thumb_nails = NULL;

-
/* --- functions --- */
void
gwm_thumb_nails_set_active (gboolean thumb_nails_enabled)
@@ -276,7 +276,7 @@
static GdkPixmap *shm_pixmap = NULL;
gint swidth = gdk_screen_width ();
gint sheight = gdk_screen_height ();
- GdkColormap *cmap = gdk_window_get_colormap (drawable);
+ GdkColormap *cmap = s_gdk_window_get_colormap (drawable);
GdkPixbuf *shot_pixbuf = NULL;
GdkVisual *visual;

@@ -286,15 +286,15 @@
*/

if (!shm_image)
- shm_image = gdk_image_new_shared_with_pixmap (NULL, swidth, SHM_IMAGE_HEIGHT, &shm_pixmap);
+ shm_image = s_gdk_image_new_shared_with_pixmap (NULL, swidth, SHM_IMAGE_HEIGHT, &shm_pixmap);

/* fallback to root window's colormap and fetch visual */
if (!cmap)
{
- visual = gdk_window_get_visual (drawable);
+ visual = s_gdk_window_get_visual (drawable);

- if (visual && visual->depth == gdk_window_get_visual (NULL)->depth)
- cmap = gdk_window_get_colormap (NULL);
+ if (visual && visual->depth == s_gdk_window_get_visual (NULL)->depth)
+ cmap = s_gdk_window_get_colormap (NULL);

if (!cmap) /* guess we're screwed */
return NULL;
@@ -338,7 +338,7 @@
shot_pixbuf = NULL;
break;
}
- gdk_pixbuf_copy_from_image (shot_pixbuf, 0, pix_y, shm_image, 0, 0, width, n, cmap);
+ s_gdk_pixbuf_copy_from_image (shot_pixbuf, 0, pix_y, shm_image, 0, 0, width, n, cmap);
height -= n;
y += n;
pix_y += n;
@@ -352,7 +352,7 @@
GdkImage *image;
GdkPixmap *pixmap;

- image = gdk_image_new_shared_with_pixmap (drawable, swidth, sheight, &pixmap);
+ image = s_gdk_image_new_shared_with_pixmap (drawable, swidth, sheight, &pixmap);
if (image)
{
GdkGCValues gc_values;
@@ -367,7 +367,7 @@
gdk_draw_pixmap (pixmap, gc, drawable, x, y, 0, 0, width, height);
gdk_flush ();
if (!gdk_error_trap_pop ())
- shot_pixbuf = gdk_pixbuf_from_image (image, 0, 0, width, height, cmap);
+ shot_pixbuf = s_gdk_pixbuf_from_image (image, 0, 0, width, height, cmap);
gdk_gc_unref (gc);
}

@@ -379,11 +379,11 @@
/* last resort, do it slowly ;) */
if (!shot_pixbuf)
{
- GdkImage *image = gdk_image_get (drawable, x, y, width, height);
+ GdkImage *image = s_gdk_image_get (drawable, x, y, width, height);

if (image)
{
- shot_pixbuf = gdk_pixbuf_from_image (image, 0, 0, width, height, cmap);
+ shot_pixbuf = s_gdk_pixbuf_from_image (image, 0, 0, width, height, cmap);
gdk_image_destroy (image);
}
}
@@ -527,7 +527,6 @@
return TRUE;
}

-
/* --- Gdk & GdkPixbuf compat functions --- */
#include
#include
@@ -537,8 +536,8 @@
#include
#endif /* USE_SHM */

-GdkImage*
-gdk_image_new_shared_with_pixmap (GdkWindow *window,
+static GdkImage*
+s_gdk_image_new_shared_with_pixmap (GdkWindow *window,
gint width,
gint height,
GdkPixmap **pixmap_p)
@@ -561,7 +560,7 @@
if (!window)
window = (GdkWindow*) &gdk_root_parent;
window_private = (GdkWindowPrivate*) window;
- visual = gdk_window_get_visual (window);
+ visual = s_gdk_window_get_visual (window);
if (window_private->destroyed || !visual)
return NULL;

@@ -615,10 +614,10 @@
#endif /* !USE_SHM */
}

/* fixed gdk_image_get(), so we don't crash if we get an X error
*/
-GdkImage*
-gdk_image_get (GdkWindow *window,
+static GdkImage*
+s_gdk_image_get (GdkWindow *window,
gint x,
gint y,
gint width,
@@ -640,7 +639,7 @@
}

win_private = (GdkWindowPrivate *) window;
- visual = gdk_window_get_visual (window);
+ visual = s_gdk_window_get_visual (window);
if (win_private->destroyed || width < 1 || height < 1 ||
(win_private->window_type != GDK_WINDOW_PIXMAP && !visual))
return NULL;
@@ -677,8 +676,8 @@
/* instead of bailing on NULL, return the root window's colormap,
* also, guard against XErrors
*/
-GdkColormap*
-gdk_window_get_colormap (GdkWindow *window)
+static GdkColormap*
+s_gdk_window_get_colormap (GdkWindow *window)
{
GdkWindowPrivate *window_private;
XWindowAttributes window_attributes = { 0, };
@@ -708,8 +707,8 @@
/* instead of bailing on NULL, return the root window's visual, also
* guard against XErrors
*/
-GdkVisual*
-gdk_window_get_visual (GdkWindow *window)
+static GdkVisual*
+s_gdk_window_get_visual (GdkWindow *window)
{
GdkWindowPrivate *window_private;
XWindowAttributes window_attributes = { 0, };
@@ -741,7 +740,7 @@
return NULL;
}

/* self hacked gdk_pixbuf_from_image(), lacking in gdk-pixbuf.
* mostly ripped from the gdk_pixbuf_get_from_drawable() implementation
*/
static void
@@ -876,8 +875,8 @@
x, y, width, height, cmap);
}

-void
-gdk_pixbuf_copy_from_image (GdkPixbuf *pixbuf,
+static void
+s_gdk_pixbuf_copy_from_image (GdkPixbuf *pixbuf,
guint dest_x,
guint dest_y,
GdkImage *image,
@@ -909,8 +908,8 @@
cmap);
}

-GdkPixbuf*
-gdk_pixbuf_from_image (GdkImage *image,
+static GdkPixbuf*
+s_gdk_pixbuf_from_image (GdkImage *image,
guint x,
guint y,
guint width,
@@ -615,10 +614,10 @@
}

-/* fixed gdk_image_get(), so we don't crash if we get an X error
+/* fixed s_gdk_image_get(), so we don't crash if we get an X error
*/
@@ -741,7 +740,7 @@
}

-/* self hacked gdk_pixbuf_from_image(), lacking in gdk-pixbuf.
+/* self hacked s_gdk_pixbuf_from_image(), lacking in gdk-pixbuf.
* mostly ripped from the gdk_pixbuf_get_from_drawable() implementation
*/
diff -Naur gnome-core-1.4.1-0001/applets/desk-guide/gwmthumbnail.c gnome-core-1.4.1-0002/applets/desk-guide/gwmthumbnail.c
--- gnome-core-1.4.1-0001/applets/desk-guide/gwmthumbnail.c 2001-10-26 05:12:47.000000000 -0400
+++ gnome-core-1.4.1-0002/applets/desk-guide/gwmthumbnail.c 2006-03-19 21:50:02.000000000 -0500
@@ -18,35 +18,38 @@
*/
#include "gwmthumbnail.h"

-
#define USE_SHM // FIXME

#define EPSILON (1.0/65536.0) /* 16bit EPSILON should be good enough */

-
/* --- defines --- */
#define SHM_IMAGE_HEIGHT (32)

-
/* --- Gdk & GdkPixbuf compat prototypes --- */
-GdkImage* gdk_image_get (GdkWindow *window,
+static
+GdkImage* s_gdk_image_get (GdkWindow *window,
gint x,
gint y,
gint width,
gint height);
-GdkColormap* gdk_window_get_colormap (GdkWindow *window);
-GdkVisual* gdk_window_get_visual (GdkWindow *window);
-GdkImage* gdk_image_new_shared_with_pixmap (GdkWindow *window,
+static
+GdkColormap* s_gdk_window_get_colormap (GdkWindow *window);
+static
+GdkVisual* s_gdk_window_get_visual (GdkWindow *window);
+static
+GdkImage* s_gdk_image_new_shared_with_pixmap (GdkWindow *window,
gint width,
gint height,
GdkPixmap **pixmap_p);
-GdkPixbuf* gdk_pixbuf_from_image (GdkImage *image,
+static
+GdkPixbuf* s_gdk_pixbuf_from_image (GdkImage *image,
guint x,
guint y,
guint width,
guint height,
GdkColormap *cmap);
-void gdk_pixbuf_copy_from_image (GdkPixbuf *pixbuf,
+static
+void s_gdk_pixbuf_copy_from_image (GdkPixbuf *pixbuf,
guint dest_x,
guint dest_y,
GdkImage *image,
@@ -56,7 +59,6 @@
guint height,
GdkColormap *cmap);

-
/* --- structures --- */
typedef struct _ThumbSize ThumbSize;
struct _ThumbSize
@@ -67,12 +69,10 @@
guint height;
};

-
/* --- variables --- */
static gboolean gwm_thumb_nails_enabled = FALSE;
static GSList *gwm_thumb_nails = NULL;

-
/* --- functions --- */
void
gwm_thumb_nails_set_active (gboolean thumb_nails_enabled)
@@ -276,7 +276,7 @@
static GdkPixmap *shm_pixmap = NULL;
gint swidth = gdk_screen_width ();
gint sheight = gdk_screen_height ();
- GdkColormap *cmap = gdk_window_get_colormap (drawable);
+ GdkColormap *cmap = s_gdk_window_get_colormap (drawable);
GdkPixbuf *shot_pixbuf = NULL;
GdkVisual *visual;

@@ -286,15 +286,15 @@
*/

if (!shm_image)
- shm_image = gdk_image_new_shared_with_pixmap (NULL, swidth, SHM_IMAGE_HEIGHT, &shm_pixmap);
+ shm_image = s_gdk_image_new_shared_with_pixmap (NULL, swidth, SHM_IMAGE_HEIGHT, &shm_pixmap);

/* fallback to root window's colormap and fetch visual */
if (!cmap)
{
- visual = gdk_window_get_visual (drawable);
+ visual = s_gdk_window_get_visual (drawable);

- if (visual && visual->depth == gdk_window_get_visual (NULL)->depth)
- cmap = gdk_window_get_colormap (NULL);
+ if (visual && visual->depth == s_gdk_window_get_visual (NULL)->depth)
+ cmap = s_gdk_window_get_colormap (NULL);

if (!cmap) /* guess we're screwed */
return NULL;
@@ -338,7 +338,7 @@
shot_pixbuf = NULL;
break;
}
- gdk_pixbuf_copy_from_image (shot_pixbuf, 0, pix_y, shm_image, 0, 0, width, n, cmap);
+ s_gdk_pixbuf_copy_from_image (shot_pixbuf, 0, pix_y, shm_image, 0, 0, width, n, cmap);
height -= n;
y += n;
pix_y += n;
@@ -352,7 +352,7 @@
GdkImage *image;
GdkPixmap *pixmap;

- image = gdk_image_new_shared_with_pixmap (drawable, swidth, sheight, &pixmap);
+ image = s_gdk_image_new_shared_with_pixmap (drawable, swidth, sheight, &pixmap);
if (image)
{
GdkGCValues gc_values;
@@ -367,7 +367,7 @@
gdk_draw_pixmap (pixmap, gc, drawable, x, y, 0, 0, width, height);
gdk_flush ();
if (!gdk_error_trap_pop ())
- shot_pixbuf = gdk_pixbuf_from_image (image, 0, 0, width, height, cmap);
+ shot_pixbuf = s_gdk_pixbuf_from_image (image, 0, 0, width, height, cmap);
gdk_gc_unref (gc);
}

@@ -379,11 +379,11 @@
/* last resort, do it slowly ;) */
if (!shot_pixbuf)
{
- GdkImage *image = gdk_image_get (drawable, x, y, width, height);
+ GdkImage *image = s_gdk_image_get (drawable, x, y, width, height);

if (image)
{
- shot_pixbuf = gdk_pixbuf_from_image (image, 0, 0, width, height, cmap);
+ shot_pixbuf = s_gdk_pixbuf_from_image (image, 0, 0, width, height, cmap);
gdk_image_destroy (image);
}
}
@@ -527,7 +527,6 @@
return TRUE;
}

-
/* --- Gdk & GdkPixbuf compat functions --- */
#include
#include
@@ -537,8 +536,8 @@
#include
#endif /* USE_SHM */

-GdkImage*
-gdk_image_new_shared_with_pixmap (GdkWindow *window,
+static GdkImage*
+s_gdk_image_new_shared_with_pixmap (GdkWindow *window,
gint width,
gint height,
GdkPixmap **pixmap_p)
@@ -561,7 +560,7 @@
if (!window)
window = (GdkWindow*) &gdk_root_parent;
window_private = (GdkWindowPrivate*) window;
- visual = gdk_window_get_visual (window);
+ visual = s_gdk_window_get_visual (window);
if (window_private->destroyed || !visual)
return NULL;

@@ -615,10 +614,10 @@
#endif /* !USE_SHM */
}

/* fixed gdk_image_get(), so we don't crash if we get an X error
*/
-GdkImage*
-gdk_image_get (GdkWindow *window,
+static GdkImage*
+s_gdk_image_get (GdkWindow *window,
gint x,
gint y,
gint width,
@@ -640,7 +639,7 @@
}

win_private = (GdkWindowPrivate *) window;
- visual = gdk_window_get_visual (window);
+ visual = s_gdk_window_get_visual (window);
if (win_private->destroyed || width < 1 || height < 1 ||
(win_private->window_type != GDK_WINDOW_PIXMAP && !visual))
return NULL;
@@ -677,8 +676,8 @@
/* instead of bailing on NULL, return the root window's colormap,
* also, guard against XErrors
*/
-GdkColormap*
-gdk_window_get_colormap (GdkWindow *window)
+static GdkColormap*
+s_gdk_window_get_colormap (GdkWindow *window)
{
GdkWindowPrivate *window_private;
XWindowAttributes window_attributes = { 0, };
@@ -708,8 +707,8 @@
/* instead of bailing on NULL, return the root window's visual, also
* guard against XErrors
*/
-GdkVisual*
-gdk_window_get_visual (GdkWindow *window)
+static GdkVisual*
+s_gdk_window_get_visual (GdkWindow *window)
{
GdkWindowPrivate *window_private;
XWindowAttributes window_attributes = { 0, };
@@ -741,7 +740,7 @@
return NULL;
}

/* self hacked gdk_pixbuf_from_image(), lacking in gdk-pixbuf.
* mostly ripped from the gdk_pixbuf_get_from_drawable() implementation
*/
static void
@@ -876,8 +875,8 @@
x, y, width, height, cmap);
}

-void
-gdk_pixbuf_copy_from_image (GdkPixbuf *pixbuf,
+static void
+s_gdk_pixbuf_copy_from_image (GdkPixbuf *pixbuf,
guint dest_x,
guint dest_y,
GdkImage *image,
@@ -909,8 +908,8 @@
cmap);
}

-GdkPixbuf*
-gdk_pixbuf_from_image (GdkImage *image,
+static GdkPixbuf*
+s_gdk_pixbuf_from_image (GdkImage *image,
guint x,
guint y,
guint width,
@@ -615,10 +614,10 @@
}

-/* fixed gdk_image_get(), so we don't crash if we get an X error
+/* fixed s_gdk_image_get(), so we don't crash if we get an X error
*/
@@ -741,7 +740,7 @@
}

-/* self hacked gdk_pixbuf_from_image(), lacking in gdk-pixbuf.
+/* self hacked s_gdk_pixbuf_from_image(), lacking in gdk-pixbuf.
* mostly ripped from the gdk_pixbuf_get_from_drawable() implementation
*/